# npc_mvr

Tools for reading raw video data from MindScope Neuropixels experiments, compatible with data in the cloud.

[![PyPI](https://img.shields.io/pypi/v/npc_mvr.svg?label=PyPI&color=blue)](https://pypi.org/project/npc_mvr/)
[![Python version](https://img.shields.io/pypi/pyversions/npc_mvr)](https://pypi.org/project/npc_mvr/)

[![Coverage](https://img.shields.io/codecov/c/github/AllenInstitute/npc_mvr?logo=codecov)](https://app.codecov.io/github/AllenInstitute/npc_mvr)
[![CI/CD](https://img.shields.io/github/actions/workflow/status/AllenInstitute/npc_mvr/publish.yml?label=CI/CD&logo=github)](https://github.com/AllenInstitute/npc_mvr/actions/workflows/publish.yml)
[![GitHub issues](https://img.shields.io/github/issues/AllenInstitute/npc_mvr?logo=github)](https://github.com/AllenInstitute/npc_mvr/issues)

# Usage
```bash
conda create -n npc_mvr python>=3.9
conda activate npc_mvr
pip install npc_mvr
```

```python
import npc_mvr
```

# Development
See instructions in https://github.com/AllenInstitute/npc_mvr/CONTRIBUTING.md and the original template: https://github.com/AllenInstitute/copier-pdm-npc/blob/main/README.md